==> developer-center-api-2.8.9.0.sunyan-20171116.083245-1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/AppNewExtraDto.java <==
package cn.com.duiba.developer.center.api.domain.dto;

import com.google.common.collect.ImmutableSet;

import java.io.Serializable;
import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.util.LinkedList;

/** 
 * @author sunyan
 * @version 创建时间：2017年4月12日 下午2:50:53
 */
public class AppNewExtraDto implements Serializable {
    private static final long serialVersionUID = -8083052631355120698L;

    public static final String SEC_KILL_VALIDATION_SLIDE = "1"; //秒杀滑动类型验证码
    public static final String SEC_KILL_VALIDATION_CLICK = "2"; //秒杀点击类型验证码
    public static final String EXCHANGE_VALIDATION_SLIDE = "1"; //普兑滑动类型验证码
    public static final String EXCHANGE_VALIDATION_CLICK = "2"; //普兑点击类型验证码

    public static final Integer CREATE_SOURCE_CREDITS = 0;//商城
    public static final Integer CREATE_SOURCE_AD = 1;//广告

    public static final String  APP_ID = "appId";
    public static final String _BD = "bd";//bd联系人
    public static final String DAILY_ACT_LOGIN_UV = "dailyActLoginUv";//上月日均活动登录UV
    public static final String ONLINE_DATE = "onlineDate";//上线日期
    public static final String FLOW_RULE = "flowRule";
    public static final String COUPON_STOCK_WARN = "couponStockWarn";//自有优惠券/虚拟商品库存预警线
    public static final String OBJECT_STOCK_WARN = "objectStockWarn";//自有实物库存预警线
    public static final String NOT_LOGIN_PLAY_GAME = "notLoginPlayGame";//未登录是否可以参与游戏
    public static final String SEC_KILL_VALIDATION_KEY = "secKillValidation"; //秒杀验证码类型
    public static final String EXCHANGE_VALIDATION_KEY = "exchangeValidation"; //普兑验证码类型
    public static final String CONSUME_VIRTUAL_CARD = "consumeVirtualCard";//扣虚拟卡链接key
    public static final String CONSUME_VIRTUAL_CARD_NOTIFY = "consumeVirtualCardNotify";//扣虚拟卡链接key
    public static final String FLOW_VIEW_TIME="flowViewTime";//流量策略展示时间key
    public static final String FLOW_RULE_GOOD_AREA="flowRuleGoodArea"; //流量策略人工干预商品区
    public static final String FLOW_RULE_FREE_LIMIT = "flowRuleFreeLimit"; //流量策略人工干预活动免费次数开关
    public static final String FLOW_RULE_FREE_LIMIT_COUNT = "flowRuleFreeLimitCount"; //流量策略人工干预活动免费次数
    public static final String FLOW_RULE_WIN_LUCKY_PROBABILITY_SWITCH = "flowRuleWinLuckyProbabilitySwitch"; //流量策略人工干预福袋中奖概率开关
    public static final String FLOW_RULE_WIN_LUCKY_PROBABILITY = "flowRuleWinLuckyProbability"; //流量策略人工干预福袋中奖概率
    public static final String CUSTOMER_SERVICE_ANDROID_SEND_PIC="customerServiceAndroidSendPic";//客服页面安卓发送图片开关
    public static final String CUSTOMER_SERVICE_SHOW_SOURCE="customerServiceShowSource";//客服页面显示来源
    public static final String CUSTOMER_SERVICE_CUSTOMER_SOURCE="customerServiceCustomerSource";//客服页面客服来源
    public static final String THANKS_TO_LUCKY_EXCLUDE_ACTIDS = "thxLuckyExcludeActIds";//谢谢参与转福袋例外的活动id列表
    public static final String THANKS_TO_LUCKY_INCLUDE_PLUGINIDS = "thxLuckyIncludePluginIds";//谢谢参与转福袋包含的插件id列表
    public static final String CREATE_SOURCE = "createSource";//app来源，0/null：兑吧，1：推啊

    public static final ImmutableSet<String> propSet;
    static {
        Field[] fields = AppNewExtraDto.class.getDeclaredFields();
        LinkedList pros = new LinkedList();
        for(int i=0; i< fields.length; i++){
            if(Modifier.isStatic(fields[i].getModifiers())){
                continue;
            }
            pros.add(fields[i].getName());
        }
        propSet = ImmutableSet.copyOf(pros);
    }

    private Long appId;
    private String bd;//bd联系人
    private String dailyActLoginUv;//上月日均活动登录UV
    private String onlineDate;//上线日期
    private Boolean flowRule;  
    private Integer couponStockWarn;//自有优惠券/虚拟商品库存预警线  
    private Integer objectStockWarn;//自有实物库存预警线
    private Boolean notLoginPlayGame;//未登录是否可以参与游戏
    private String secKillValidation; //秒杀验证码类型
    private String exchangeValidation; //普兑验证码类型
    private String consumeVirtualCard;//扣虚拟卡链接
    private String consumeVirtualCardNotify;//扣虚拟卡通知
    private String flowViewTime;//流量策略券展示时间
    private Boolean flowRuleGoodArea;//流量策略人工干预商品区
    private Boolean flowRuleFreeLimit; //流量策略人工干预活动免费次数开关
    private Integer flowRuleFreeLimitCount; //流量策略人工干预活动免费次数
    private Integer flowRuleWinLuckyProbability;//流量策略人工干预福袋中奖概率
    private Boolean flowRuleWinLuckyProbabilitySwitch;//流量策略人工干预福袋中奖概率开关
    //客服配置-安卓端显示图片
    private Boolean customerServiceAndroidSendPic;
    //客服配置-用户来源是否展示
    private Boolean customerServiceShowSource;
    //客服配置-用户来源
    private String customerServiceCustomerSource;
    /**
     * 谢谢参与转福袋例外的活动id列表
     */
    private String thxLuckyExcludeActIds;
    private Integer createSource;
    //谢谢参与转福袋的插件ids
    private String thxLuckyIncludePluginIds;

    public String getSecKillValidation() {
        return secKillValidation;
    }

    public void setSecKillValidation(String secKillValidation) {
        this.secKillValidation = secKillValidation;
    }

    public String getExchangeValidation() {
        return exchangeValidation;
    }

    public void setExchangeValidation(String exchangeValidation) {
        this.exchangeValidation = exchangeValidation;
    }

    public Long getAppId() {
        return appId;
    }
    public void setAppId(Long appId) {
        this.appId = appId;
    }
    public String getBd() {
        return bd;
    }
    public void setBd(String bd) {
        this.bd = bd;
    }
    public String getDailyActLoginUv() {
        return dailyActLoginUv;
    }
    public void setDailyActLoginUv(String dailyActLoginUv) {
        this.dailyActLoginUv = dailyActLoginUv;
    }
    public String getOnlineDate() {
        return onlineDate;
    }
    public void setOnlineDate(String onlineDate) {
        this.onlineDate = onlineDate;
    }

    public Boolean getFlowRule() {
        return flowRule;
    }

    public void setFlowRule(Boolean flowRule) {
        this.flowRule = flowRule;
    }
    public Integer getCouponStockWarn() {
        return couponStockWarn;
    }
    public void setCouponStockWarn(Integer couponStockWarn) {
        this.couponStockWarn = couponStockWarn;
    }
    public Integer getObjectStockWarn() {
        return objectStockWarn;
    }
    public void setObjectStockWarn(Integer objectStockWarn) {
        this.objectStockWarn = objectStockWarn;
    }

    public Boolean getNotLoginPlayGame() {
        return notLoginPlayGame;
    }

    public void setNotLoginPlayGame(Boolean notLoginPlayGame) {
        this.notLoginPlayGame = notLoginPlayGame;
    }

    public String getConsumeVirtualCard() {
        return consumeVirtualCard;
    }

    public void setConsumeVirtualCard(String consumeVirtualCard) {
        this.consumeVirtualCard = consumeVirtualCard;
    }

    public String getConsumeVirtualCardNotify() {
        return consumeVirtualCardNotify;
    }

    public void setConsumeVirtualCardNotify(String consumeVirtualCardNotify) {
        this.consumeVirtualCardNotify = consumeVirtualCardNotify;
    }

    public String getFlowViewTime() {
        return flowViewTime;
    }

    public void setFlowViewTime(String flowViewTime) {
        this.flowViewTime = flowViewTime;
    }

    public String getThxLuckyExcludeActIds() {
        return thxLuckyExcludeActIds;
    }

    public void setThxLuckyExcludeActIds(String thxLuckyExcludeActIds) {
        this.thxLuckyExcludeActIds = thxLuckyExcludeActIds;
    }

    public Boolean getFlowRuleGoodArea() {
        return flowRuleGoodArea;
    }

    public void setFlowRuleGoodArea(Boolean flowRuleGoodArea) {
        this.flowRuleGoodArea = flowRuleGoodArea;
    }

    public Boolean getCustomerServiceAndroidSendPic() {
        return customerServiceAndroidSendPic;
    }

    public void setCustomerServiceAndroidSendPic(Boolean customerServiceAndroidSendPic) {
        this.customerServiceAndroidSendPic = customerServiceAndroidSendPic;
    }

    public Boolean getCustomerServiceShowSource() {
        return customerServiceShowSource;
    }

    public void setCustomerServiceShowSource(Boolean customerServiceShowSource) {
        this.customerServiceShowSource = customerServiceShowSource;
    }

    public String getCustomerServiceCustomerSource() {
        return customerServiceCustomerSource;
    }

    public void setCustomerServiceCustomerSource(String customerServiceCustomerSource) {
        this.customerServiceCustomerSource = customerServiceCustomerSource;
    }

    public Boolean getFlowRuleFreeLimit() {
        return flowRuleFreeLimit;
    }

    public void setFlowRuleFreeLimit(Boolean flowRuleFreeLimit) {
        this.flowRuleFreeLimit = flowRuleFreeLimit;
    }

    public Integer getFlowRuleFreeLimitCount() {
        return flowRuleFreeLimitCount;
    }

    public void setFlowRuleFreeLimitCount(Integer flowRuleFreeLimitCount) {
        this.flowRuleFreeLimitCount = flowRuleFreeLimitCount;
    }

    public Integer getCreateSource() {
        return createSource;
    }

    public void setCreateSource(Integer createSource) {
        this.createSource = createSource;
    }

    public String getThxLuckyIncludePluginIds() {
        return thxLuckyIncludePluginIds;
    }

    public void setThxLuckyIncludePluginIds(String thxLuckyIncludePluginIds) {
        this.thxLuckyIncludePluginIds = thxLuckyIncludePluginIds;
    }

    public Integer getFlowRuleWinLuckyProbability() {
        return flowRuleWinLuckyProbability;
    }

    public void setFlowRuleWinLuckyProbability(Integer flowRuleWinLuckyProbability) {
        this.flowRuleWinLuckyProbability = flowRuleWinLuckyProbability;
    }

    public Boolean getFlowRuleWinLuckyProbabilitySwitch() {
        return flowRuleWinLuckyProbabilitySwitch;
    }

    public void setFlowRuleWinLuckyProbabilitySwitch(Boolean flowRuleWinLuckyProbabilitySwitch) {
        this.flowRuleWinLuckyProbabilitySwitch = flowRuleWinLuckyProbabilitySwitch;
    }
}

==> developer-center-api-2.9.5.sunyan-20171128.022635-1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/AppNewExtraDto.java <==
package cn.com.duiba.developer.center.api.domain.dto;

import com.google.common.collect.ImmutableSet;

import java.io.Serializable;
import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.util.LinkedList;

/** 
 * @author sunyan
 * @version 创建时间：2017年4月12日 下午2:50:53
 */
public class AppNewExtraDto implements Serializable {
    private static final long serialVersionUID = -8083052631355120698L;

    public static final String SEC_KILL_VALIDATION_SLIDE = "1"; //秒杀滑动类型验证码
    public static final String SEC_KILL_VALIDATION_CLICK = "2"; //秒杀点击类型验证码
    public static final String EXCHANGE_VALIDATION_SLIDE = "1"; //普兑滑动类型验证码
    public static final String EXCHANGE_VALIDATION_CLICK = "2"; //普兑点击类型验证码

    public static final Integer CREATE_SOURCE_CREDITS = 0;//商城
    public static final Integer CREATE_SOURCE_AD = 1;//广告

    public static final String  APP_ID = "appId";
    public static final String _BD = "bd";//bd联系人
    public static final String DAILY_ACT_LOGIN_UV = "dailyActLoginUv";//上月日均活动登录UV
    public static final String ONLINE_DATE = "onlineDate";//上线日期
    public static final String FLOW_RULE = "flowRule";
    public static final String COUPON_STOCK_WARN = "couponStockWarn";//自有优惠券/虚拟商品库存预警线
    public static final String OBJECT_STOCK_WARN = "objectStockWarn";//自有实物库存预警线
    public static final String NOT_LOGIN_PLAY_GAME = "notLoginPlayGame";//未登录是否可以参与游戏
    public static final String SEC_KILL_VALIDATION_KEY = "secKillValidation"; //秒杀验证码类型
    public static final String EXCHANGE_VALIDATION_KEY = "exchangeValidation"; //普兑验证码类型
    public static final String CONSUME_VIRTUAL_CARD = "consumeVirtualCard";//扣虚拟卡链接key
    public static final String CONSUME_VIRTUAL_CARD_NOTIFY = "consumeVirtualCardNotify";//扣虚拟卡链接key
    public static final String FLOW_VIEW_TIME="flowViewTime";//流量策略展示时间key
    public static final String FLOW_RULE_GOOD_AREA="flowRuleGoodArea"; //流量策略人工干预商品区
    public static final String FLOW_RULE_FREE_LIMIT = "flowRuleFreeLimit"; //流量策略人工干预活动免费次数开关
    public static final String FLOW_RULE_FREE_LIMIT_COUNT = "flowRuleFreeLimitCount"; //流量策略人工干预活动免费次数
    public static final String FLOW_RULE_WIN_LUCKY_PROBABILITY_SWITCH = "flowRuleWinLuckyProbabilitySwitch"; //流量策略人工干预福袋中奖概率开关
    public static final String FLOW_RULE_WIN_LUCKY_PROBABILITY = "flowRuleWinLuckyProbability"; //流量策略人工干预福袋中奖概率
    public static final String CUSTOMER_SERVICE_ANDROID_SEND_PIC="customerServiceAndroidSendPic";//客服页面安卓发送图片开关
    public static final String CUSTOMER_SERVICE_SHOW_SOURCE="customerServiceShowSource";//客服页面显示来源
    public static final String CUSTOMER_SERVICE_CUSTOMER_SOURCE="customerServiceCustomerSource";//客服页面客服来源
    public static final String CUSTOMER_SERVICE_CUSTOMER_VIP="customerServiceCustomerVip";//客服页面客服来源
    public static final String THANKS_TO_LUCKY_EXCLUDE_ACTIDS = "thxLuckyExcludeActIds";//谢谢参与转福袋例外的活动id列表
    public static final String THANKS_TO_LUCKY_INCLUDE_PLUGINIDS = "thxLuckyIncludePluginIds";//谢谢参与转福袋包含的插件id列表
    public static final String CREATE_SOURCE = "createSource";//app来源，0/null：兑吧，1：推啊
    public static final String DELIVER_OBJECT_ORDER_NOTIFY = "deliverObjectOrderNotify";//实物订单通知接口地址
    public static final String FLOOR_MORE_TASK_SWITCH = "floorMoreTaskSwitch";  //任务楼层更多任务开关
    public static final String FLOOR_MORE_TASK_LINKURL = "floorMoreTaskLinkUrl"; //任务路程更多任务链接url

    public static final ImmutableSet<String> propSet;
    static {
        Field[] fields = AppNewExtraDto.class.getDeclaredFields();
        LinkedList pros = new LinkedList();
        for(int i=0; i< fields.length; i++){
            if(Modifier.isStatic(fields[i].getModifiers())){
                continue;
            }
            pros.add(fields[i].getName());
        }
        propSet = ImmutableSet.copyOf(pros);
    }

    private Long appId;
    private String bd;//bd联系人
    private String dailyActLoginUv;//上月日均活动登录UV
    private String onlineDate;//上线日期
    private Boolean flowRule;  
    private Integer couponStockWarn;//自有优惠券/虚拟商品库存预警线  
    private Integer objectStockWarn;//自有实物库存预警线
    private Boolean notLoginPlayGame;//未登录是否可以参与游戏
    private String secKillValidation; //秒杀验证码类型
    private String exchangeValidation; //普兑验证码类型
    private String consumeVirtualCard;//扣虚拟卡链接
    private String consumeVirtualCardNotify;//扣虚拟卡通知
    private String flowViewTime;//流量策略券展示时间
    private Boolean flowRuleGoodArea;//流量策略人工干预商品区
    private Boolean flowRuleFreeLimit; //流量策略人工干预活动免费次数开关
    private Integer flowRuleFreeLimitCount; //流量策略人工干预活动免费次数
    private Integer flowRuleWinLuckyProbability;//流量策略人工干预福袋中奖概率
    private Boolean flowRuleWinLuckyProbabilitySwitch;//流量策略人工干预福袋中奖概率开关
    //客服配置-安卓端显示图片
    private Boolean customerServiceAndroidSendPic;
    //客服配置-用户来源是否展示
    private Boolean customerServiceShowSource;
    //客服配置-用户来源
    private String customerServiceCustomerSource;
    /**
     * 谢谢参与转福袋例外的活动id列表
     */
    private String thxLuckyExcludeActIds;
    private Integer createSource;
    //谢谢参与转福袋的插件ids
    private String thxLuckyIncludePluginIds;

    private Boolean  floorMoreTaskSwitch;
    private String  floorMoreTaskLinkUrl;
    /**
     * 实物订单通知接口地址
     */
    private String deliverObjectOrderNotify;

    public String getDeliverObjectOrderNotify() {
        return deliverObjectOrderNotify;
    }

    public void setDeliverObjectOrderNotify(String deliverObjectOrderNotify) {
        this.deliverObjectOrderNotify = deliverObjectOrderNotify;
    }

    public String getSecKillValidation() {
        return secKillValidation;
    }

    public void setSecKillValidation(String secKillValidation) {
        this.secKillValidation = secKillValidation;
    }

    public String getExchangeValidation() {
        return exchangeValidation;
    }

    public void setExchangeValidation(String exchangeValidation) {
        this.exchangeValidation = exchangeValidation;
    }

    public Long getAppId() {
        return appId;
    }
    public void setAppId(Long appId) {
        this.appId = appId;
    }
    public String getBd() {
        return bd;
    }
    public void setBd(String bd) {
        this.bd = bd;
    }
    public String getDailyActLoginUv() {
        return dailyActLoginUv;
    }
    public void setDailyActLoginUv(String dailyActLoginUv) {
        this.dailyActLoginUv = dailyActLoginUv;
    }
    public String getOnlineDate() {
        return onlineDate;
    }
    public void setOnlineDate(String onlineDate) {
        this.onlineDate = onlineDate;
    }

    public Boolean getFlowRule() {
        return flowRule;
    }

    public void setFlowRule(Boolean flowRule) {
        this.flowRule = flowRule;
    }
    public Integer getCouponStockWarn() {
        return couponStockWarn;
    }
    public void setCouponStockWarn(Integer couponStockWarn) {
        this.couponStockWarn = couponStockWarn;
    }
    public Integer getObjectStockWarn() {
        return objectStockWarn;
    }
    public void setObjectStockWarn(Integer objectStockWarn) {
        this.objectStockWarn = objectStockWarn;
    }

    public Boolean getNotLoginPlayGame() {
        return notLoginPlayGame;
    }

    public void setNotLoginPlayGame(Boolean notLoginPlayGame) {
        this.notLoginPlayGame = notLoginPlayGame;
    }

    public String getConsumeVirtualCard() {
        return consumeVirtualCard;
    }

    public void setConsumeVirtualCard(String consumeVirtualCard) {
        this.consumeVirtualCard = consumeVirtualCard;
    }

    public String getConsumeVirtualCardNotify() {
        return consumeVirtualCardNotify;
    }

    public void setConsumeVirtualCardNotify(String consumeVirtualCardNotify) {
        this.consumeVirtualCardNotify = consumeVirtualCardNotify;
    }

    public String getFlowViewTime() {
        return flowViewTime;
    }

    public void setFlowViewTime(String flowViewTime) {
        this.flowViewTime = flowViewTime;
    }

    public String getThxLuckyExcludeActIds() {
        return thxLuckyExcludeActIds;
    }

    public void setThxLuckyExcludeActIds(String thxLuckyExcludeActIds) {
        this.thxLuckyExcludeActIds = thxLuckyExcludeActIds;
    }

    public Boolean getFlowRuleGoodArea() {
        return flowRuleGoodArea;
    }

    public void setFlowRuleGoodArea(Boolean flowRuleGoodArea) {
        this.flowRuleGoodArea = flowRuleGoodArea;
    }

    public Boolean getCustomerServiceAndroidSendPic() {
        return customerServiceAndroidSendPic;
    }

    public void setCustomerServiceAndroidSendPic(Boolean customerServiceAndroidSendPic) {
        this.customerServiceAndroidSendPic = customerServiceAndroidSendPic;
    }

    public Boolean getCustomerServiceShowSource() {
        return customerServiceShowSource;
    }

    public void setCustomerServiceShowSource(Boolean customerServiceShowSource) {
        this.customerServiceShowSource = customerServiceShowSource;
    }

    public String getCustomerServiceCustomerSource() {
        return customerServiceCustomerSource;
    }

    public void setCustomerServiceCustomerSource(String customerServiceCustomerSource) {
        this.customerServiceCustomerSource = customerServiceCustomerSource;
    }

    public Boolean getFlowRuleFreeLimit() {
        return flowRuleFreeLimit;
    }

    public void setFlowRuleFreeLimit(Boolean flowRuleFreeLimit) {
        this.flowRuleFreeLimit = flowRuleFreeLimit;
    }

    public Integer getFlowRuleFreeLimitCount() {
        return flowRuleFreeLimitCount;
    }

    public void setFlowRuleFreeLimitCount(Integer flowRuleFreeLimitCount) {
        this.flowRuleFreeLimitCount = flowRuleFreeLimitCount;
    }

    public Integer getCreateSource() {
        return createSource;
    }

    public void setCreateSource(Integer createSource) {
        this.createSource = createSource;
    }

    public String getThxLuckyIncludePluginIds() {
        return thxLuckyIncludePluginIds;
    }

    public void setThxLuckyIncludePluginIds(String thxLuckyIncludePluginIds) {
        this.thxLuckyIncludePluginIds = thxLuckyIncludePluginIds;
    }

    public Integer getFlowRuleWinLuckyProbability() {
        return flowRuleWinLuckyProbability;
    }

    public void setFlowRuleWinLuckyProbability(Integer flowRuleWinLuckyProbability) {
        this.flowRuleWinLuckyProbability = flowRuleWinLuckyProbability;
    }

    public Boolean getFlowRuleWinLuckyProbabilitySwitch() {
        return flowRuleWinLuckyProbabilitySwitch;
    }

    public void setFlowRuleWinLuckyProbabilitySwitch(Boolean flowRuleWinLuckyProbabilitySwitch) {
        this.flowRuleWinLuckyProbabilitySwitch = flowRuleWinLuckyProbabilitySwitch;
    }

    public Boolean getFloorMoreTaskSwitch() {
        return floorMoreTaskSwitch;
    }

    public void setFloorMoreTaskSwitch(Boolean floorMoreTaskSwitch) {
        this.floorMoreTaskSwitch = floorMoreTaskSwitch;
    }

    public String getFloorMoreTaskLinkUrl() {
        return floorMoreTaskLinkUrl;
    }

    public void setFloorMoreTaskLinkUrl(String floorMoreTaskLinkUrl) {
        this.floorMoreTaskLinkUrl = floorMoreTaskLinkUrl;
    }
}
